<!--
Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com

This work is licensed under the Creative Commons Attribution-ShareAlike 4.0
International License. To view a copy of this license, visit
http://creativecommons.org/licenses/by-sa/4.0/ or send a letter to Creative
Commons, PO Box 1866, Mountain View, CA 94042, USA.
-->

# gemseo-pdfo

[![PyPI - License](https://img.shields.io/pypi/l/gemseo-pdfo)](https://www.gnu.org/licenses/lgpl-3.0.en.html)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/gemseo-pdfo)](https://pypi.org/project/gemseo-pdfo/)
[![PyPI](https://img.shields.io/pypi/v/gemseo-pdfo)](https://pypi.org/project/gemseo-pdfo/)
[![Codecov branch](https://img.shields.io/codecov/c/gitlab/gemseo:dev/gemseo-pdfo/develop)](https://app.codecov.io/gl/gemseo:dev/gemseo-pdfo)

## Overview

PDFO wrapper for GEMSEO

## Installation

Install the latest version with `pip install gemseo-pdfo`.

See [pip](https://pip.pypa.io/en/stable/getting-started/) for more information.

## Bugs and questions

Please use the [gitlab issue tracker](https://gitlab.com/gemseo/dev/gemseo-pdfo/-/issues)
to submit bugs or questions.

## Contributing

See the [contributing section of GEMSEO](https://gemseo.readthedocs.io/en/stable/software/developing.html#dev).

## Contributors

- GEMSEO developers

## References

Ragonneau, T.M., Zhang, Z. PDFO: a cross-platform package for Powell’s derivative-free optimization solvers.
Math. Prog. Comp. 16, 535–559 (2024). https://doi.org/10.1007/s12532-024-00257-9
